
# Slot: meaning


the value meaning (in the 11179 sense) of a permissible value

URI: [linkml:meaning](https://w3id.org/linkml/meaning)


## Domain and Range

[PermissibleValue](PermissibleValue.md) &#8594;  <sub>0..1</sub> [Uriorcurie](Uriorcurie.md)

## Parents


## Children


## Used by

 * [PermissibleValue](PermissibleValue.md)
